@@ -565,13 +565,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   105,   105,   106,   107,   110,   176,   177,   180,   181,
-     182,   183,   184,   185,   186,   187,   188,   189,   190,   191,
-     192,   193,   194,   197,   198,   199,   200,   201,   202,   203,
-     204,   205,   206,   207,   208,   209,   212,   213,   214,   215,
-     216,   217,   218,   219,   220,   221,   222,   223,   224,   225,
-     226,   227,   228,   229,   230,   231,   232,   233,   234,   235,
-     236,   237,   238,   239,   240,   241
+       0,   105,   105,   106,   107,   110,   177,   178,   181,   182,
+     183,   184,   185,   186,   187,   188,   189,   190,   191,   192,
+     193,   194,   195,   198,   199,   200,   201,   202,   203,   204,
+     205,   206,   207,   208,   209,   210,   213,   214,   215,   216,
+     217,   218,   219,   220,   221,   222,   223,   224,   225,   226,
+     227,   228,   229,   230,   231,   232,   233,   234,   235,   236,
+     237,   238,   239,   240,   241,   242
 };
 #endif
 
@@ -1626,7 +1626,8 @@ yyreduce:
 		if (cmd_calc) {
 			struct symtab *st = NULL;
 			set_symtab((yyvsp[(1) - (1)].expr), st);
-			set_ordering((yyvsp[(1) - (1)].expr), caring);
+			// we can use agnostic here as we are getting a scalar anyway.
+			set_ordering((yyvsp[(1) - (1)].expr), agnostic);
 			struct val_list *vl = eval((yyvsp[(1) - (1)].expr));
 			struct val_list *cl = vl;
 			cl = list_sort(cl);
@@ -1671,312 +1672,312 @@ yyreduce:
 				cl = cl->next;
 			}
 		}
-	;}
+	}
     break;
 
   case 6:
-#line 176 "par.y"
-    { (yyval.expr) = (yyvsp[(1) - (1)].expr); ;}
+#line 177 "par.y"
+    { (yyval.expr) = (yyvsp[(1) - (1)].expr); }
     break;
 
   case 7:
-#line 177 "par.y"
-    { (yyval.expr) = (yyvsp[(1) - (1)].expr); ;}
+#line 178 "par.y"
+    { (yyval.expr) = (yyvsp[(1) - (1)].expr); }
     break;
 
   case 8:
-#line 180 "par.y"
-    { (yyval.expr) = number_create((yyvsp[(1) - (1)].ival)); ;}
+#line 181 "par.y"
+    { (yyval.expr) = number_create((yyvsp[(1) - (1)].ival)); }
     break;
 
   case 9:
-#line 181 "par.y"
-    { (yyval.expr) = variable_create((yyvsp[(1) - (1)].tval)); ;}
+#line 182 "par.y"
+    { (yyval.expr) = variable_create((yyvsp[(1) - (1)].tval)); }
     break;
 
   case 10:
-#line 182 "par.y"
-    { (yyval.expr) = (yyvsp[(2) - (3)].expr); ;}
+#line 183 "par.y"
+    { (yyval.expr) = (yyvsp[(2) - (3)].expr); }
     break;
 
   case 11:
-#line 183 "par.y"
-    { (yyval.expr) = negate_create((yyvsp[(2) - (2)].expr)); ;}
+#line 184 "par.y"
+    { (yyval.expr) = negate_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 12:
-#line 184 "par.y"
-    { (yyval.expr) = plus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 185 "par.y"
+    { (yyval.expr) = plus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 13:
-#line 185 "par.y"
-    { (yyval.expr) = minus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 186 "par.y"
+    { (yyval.expr) = minus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 14:
-#line 186 "par.y"
-    { (yyval.expr) = multi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 187 "par.y"
+    { (yyval.expr) = multi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 15:
-#line 187 "par.y"
-    { (yyval.expr) = divi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 188 "par.y"
+    { (yyval.expr) = divi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 16:
-#line 188 "par.y"
-    { (yyval.expr) = mod_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 189 "par.y"
+    { (yyval.expr) = mod_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 17:
-#line 189 "par.y"
-    { (yyval.expr) = expo_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 190 "par.y"
+    { (yyval.expr) = expo_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 18:
-#line 190 "par.y"
-    { (yyval.expr) = scat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 191 "par.y"
+    { (yyval.expr) = scat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 19:
-#line 191 "par.y"
-    { (yyval.expr) = dice_create((yyvsp[(2) - (2)].expr)); ;}
+#line 192 "par.y"
+    { (yyval.expr) = dice_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 20:
-#line 192 "par.y"
-    { (yyval.expr) = sum_create((yyvsp[(2) - (2)].expr)); ;}
+#line 193 "par.y"
+    { (yyval.expr) = sum_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 21:
-#line 193 "par.y"
-    { (yyval.expr) = prod_create((yyvsp[(2) - (2)].expr)); ;}
+#line 194 "par.y"
+    { (yyval.expr) = prod_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 22:
-#line 194 "par.y"
-    { (yyval.expr) = count_create((yyvsp[(2) - (2)].expr)); ;}
+#line 195 "par.y"
+    { (yyval.expr) = count_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 23:
-#line 197 "par.y"
-    { (yyval.expr) = rep_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 198 "par.y"
+    { (yyval.expr) = rep_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 24:
-#line 198 "par.y"
-    { (yyval.expr) = (yyvsp[(2) - (3)].expr); ;}
+#line 199 "par.y"
+    { (yyval.expr) = (yyvsp[(2) - (3)].expr); }
     break;
 
   case 25:
-#line 199 "par.y"
-    { (yyval.expr) = elist_create(); ;}
+#line 200 "par.y"
+    { (yyval.expr) = elist_create(); }
     break;
 
   case 26:
-#line 200 "par.y"
-    { (yyval.expr) = range_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 201 "par.y"
+    { (yyval.expr) = range_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 27:
-#line 201 "par.y"
-    { (yyval.expr) = lcat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
+#line 202 "par.y"
+    { (yyval.expr) = lcat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 28:
-#line 202 "par.y"
-    { (yyval.expr) = perm_create((yyvsp[(2) - (2)].expr)); ;}
+#line 203 "par.y"
+    { (yyval.expr) = perm_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 29:
-#line 203 "par.y"
-    { (yyval.expr) = sort_create((yyvsp[(2) - (2)].expr)); ;}
+#line 204 "par.y"
+    { (yyval.expr) = sort_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 30:
-#line 204 "par.y"
-    { (yyval.expr) = rev_create((yyvsp[(2) - (2)].expr)); ;}
+#line 205 "par.y"
+    { (yyval.expr) = rev_create((yyvsp[(2) - (2)].expr)); }
     break;
 
   case 31:
-#line 205 "par.y"
-    { (yyval.expr) = (yyvsp[(1) - (1)].expr); ;}
+#line 206 "par.y"
+    { (yyval.expr) = (yyvsp[(1) - (1)].expr); }
     break;
 
   case 32:
-#line 206 "par.y"
-    { (yyval.expr) = ifthenelse_create((yyvsp[(2) - (6)].expr), (yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr)); ;}
+#line 207 "par.y"
+    { (yyval.expr) = ifthenelse_create((yyvsp[(2) - (6)].expr), (yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr)); }
     break;
 
   case 33:
-#line 207 "par.y"
-    { (yyval.expr) = let_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); ;}
+#line 208 "par.y"
+    { (yyval.expr) = let_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); }
     break;
 
   case 34:
-#line 208 "par.y"
-    { (yyval.expr) = whiledo_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); ;}
+#line 209 "par.y"
+    { (yyval.expr) = whiledo_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); }
     break;
 
   case 35:
-#line 209 "par.y"
-    { (yyval.expr) = foreach_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); ;}
+#line 210 "par.y"
+    { (yyval.expr) = foreach_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); }
     break;
 
   case 36:
-#line 212 "par.y"
-    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
+#line 213 "par.y"
+    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
     break;
 
   case 37:
-#line 213 "par.y"
-    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
+#line 214 "par.y"
+    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
     break;
 
   case 38:
-#line 214 "par.y"
-    { (yyval.expr) = first_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
+#line 215 "par.y"
+    { (yyval.expr) = first_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
     break;
 
   case 39:
-#line 215 "par.y"
-    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
+#line 216 "par.y"
+    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
     break;
 
   case 40:
-#line 216 "par.y"
-    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
+#line 217 "par.y"
+    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
     break;
 
   case 41:
-#line 217 "par.y"
-    { (yyval.expr) = last_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
+#line 218 "par.y"
+    { (yyval.expr) = last_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
     break;
 
   case 42:
-#line 218 "par.y"
-    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
+#line 219 "par.y"
+    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
     break;
 
   case 43:
-#line 219 "par.y"
-    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
+#line 220 "par.y"
+    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
     break;
 
   case 44:
-#line 220 "par.y"
-    { (yyval.expr) = high_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
+#line 221 "par.y"
+    { (yyval.expr) = high_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
     break;
 
   case 45:
-#line 221 "par.y"
-    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
+#line 222 "par.y"
+    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
     break;
 
   case 46:
-#line 222 "par.y"
-    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
+#line 223 "par.y"
+    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
     break;
 
   case 47:
-#line 223 "par.y"
-    { (yyval.expr) = low_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
+#line 224 "par.y"
+    { (yyval.expr) = low_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
     break;
 
   case 48:
-#line 224 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, eq); ;}
+#line 225 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, eq); }
     break;
 
   case 49:
-#line 225 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, eq); ;}
+#line 226 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, eq); }
     break;
 
   case 50:
-#line 226 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, eq); ;}
+#line 227 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, eq); }
     break;
 
   case 51:
-#line 227 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ne); ;}
+#line 228 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ne); }
     break;
 
   case 52:
-#line 228 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ne); ;}
+#line 229 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ne); }
     break;
 
   case 53:
-#line 229 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ne); ;}
+#line 230 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ne); }
     break;
 
   case 54:
-#line 230 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, gt); ;}
+#line 231 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, gt); }
     break;
 
   case 55:
-#line 231 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, gt); ;}
+#line 232 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, gt); }
     break;
 
   case 56:
-#line 232 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, gt); ;}
+#line 233 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, gt); }
     break;
 
   case 57:
-#line 233 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, lt); ;}
+#line 234 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, lt); }
     break;
 
   case 58:
-#line 234 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, lt); ;}
+#line 235 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, lt); }
     break;
 
   case 59:
-#line 235 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, lt); ;}
+#line 236 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, lt); }
     break;
 
   case 60:
-#line 236 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ge); ;}
+#line 237 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ge); }
     break;
 
   case 61:
-#line 237 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ge); ;}
+#line 238 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ge); }
     break;
 
   case 62:
-#line 238 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ge); ;}
+#line 239 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ge); }
     break;
 
   case 63:
-#line 239 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, le); ;}
+#line 240 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, le); }
     break;
 
   case 64:
-#line 240 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, le); ;}
+#line 241 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, le); }
     break;
 
   case 65:
-#line 241 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, le); ;}
+#line 242 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, le); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1980 "par.c"
+#line 1981 "par.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2190,7 +2191,7 @@ yyreturn:
 }
 
 
-#line 243 "par.y"
+#line 244 "par.y"
 
 
 int yyerror(char *s) {
